==> ag_1.14.0.tar.gz: ag/man/agPMID.Rd <==
\name{agPMID}
\alias{agPMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   agPMID is an R environment that provides mappings between
   manufacturer identifiers and PubMed identifiers.
}
\details{
  Each manufacturer identifier is mapped to a named vector of PubMed identifiers. The
  name associated with each vector corresponds to the manufacturer
  identifier. The length of the vector may be one or greater, depending on how
  many PubMed identifiers a given manufacturer identifier is mapped to. An \code{NA} is
  reported for any manufacturer identifier that cannot be mapped to a PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy_AG_array_elements-2006-07-14.txt}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/User_Requests/LocusPublished.08012006.txt}
Built: N/A

  Package built Wed Sep  6 11:22:37 2006
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(agPMID)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}

==> ag_1.16.1.tar.gz: ag/man/agPMID.Rd <==
\name{agPMID}
\alias{agPMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   agPMID is an R environment that provides mappings between
   manufacturer identifiers and PubMed identifiers.
}
\details{
  Each manufacturer identifier is mapped to a named vector of PubMed identifiers. The
  name associated with each vector corresponds to the manufacturer
  identifier. The length of the vector may be one or greater, depending on how
  many PubMed identifiers a given manufacturer identifier is mapped to. An \code{NA} is
  reported for any manufacturer identifier that cannot be mapped to a PubMed identifier.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed identifier. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Microarrays/Affymetrix/affy\_AG\_array\_elements-2006-07-14.txt}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR\_sequenced\_genes}
Tair: \\url{ftp://ftp.arabidopsis.org/home/tair/User\_Requests/LocusPublished.02022007}
Built: N/A

  Package built Thu Mar 15 17:42:16 2007
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(agPMID)
    if(length(xx) > 0){
        # The probe identifiers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}
